"""
Generated class for ClaimResponse. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.Address import *
from fhirmodels.R4.Attachment import *
from fhirmodels.R4.BackboneElement import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Identifier import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Money import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Period import *
from fhirmodels.R4.Quantity import *
from fhirmodels.R4.Reference import *
from fhirmodels.R4.Resource import *


class Adjudication(FhirBaseModel):
    """If this item is a group then the values here are a summary of the adjudication of the detail items. If this item is a simple product or service then this is the result of the adjudication of this item.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept category: Type of adjudication information
    :param CodeableConcept reason: Explanation of adjudication outcome
    :param Money amount: Monetary amount
    :param float value: Non-monetary value
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "reason": {"class_name": "CodeableConcept", "is_contained": False},
        "amount": {"class_name": "Money", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        category: "CodeableConcept" = None,
        reason: "CodeableConcept" = None,
        amount: "Money" = None,
        value: "float" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.category = category
        self.reason = reason
        self.amount = amount
        self.value = value

    @classmethod
    def from_dict(cls, data: dict) -> "ClaimResponse":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ClaimResponse":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class SubDetail(FhirBaseModel):
    """A sub-detail adjudication of a simple product or service.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int subDetailSequence: Claim sub-detail instance identifier
    :param int noteNumber: Applicable note numbers
    :param Adjudication adjudication: Subdetail level adjudication details
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "adjudication": {"class_name": "Adjudication", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        subDetailSequence: "int" = None,
        noteNumber: list["int"] = None,
        adjudication: list["Adjudication"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.subDetailSequence = subDetailSequence
        self.noteNumber = noteNumber or []
        self.adjudication = adjudication or []

    @classmethod
    def from_dict(cls, data: dict) -> "ClaimResponse":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ClaimResponse":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Detail(FhirBaseModel):
    """A claim detail. Either a simple (a product or service) or a 'group' of sub-details which are simple items.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int detailSequence: Claim detail instance identifier
    :param int noteNumber: Applicable note numbers
    :param Adjudication adjudication: Detail level adjudication details
    :param SubDetail subDetail: Adjudication for claim sub-details
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "adjudication": {"class_name": "Adjudication", "is_contained": True},
        "subDetail": {"class_name": "SubDetail", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        detailSequence: "int" = None,
        noteNumber: list["int"] = None,
        adjudication: list["Adjudication"] = None,
        subDetail: list["SubDetail"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.detailSequence = detailSequence
        self.noteNumber = noteNumber or []
        self.adjudication = adjudication or []
        self.subDetail = subDetail or []

    @classmethod
    def from_dict(cls, data: dict) -> "ClaimResponse":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ClaimResponse":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Item(FhirBaseModel):
    """A claim line. Either a simple (a product or service) or a 'group' of details which can also be a simple items or groups of sub-details.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int itemSequence: Claim item instance identifier
    :param int noteNumber: Applicable note numbers
    :param Adjudication adjudication: Adjudication details
    :param Detail detail: Adjudication for claim details
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "adjudication": {"class_name": "Adjudication", "is_contained": True},
        "detail": {"class_name": "Detail", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        itemSequence: "int" = None,
        noteNumber: list["int"] = None,
        adjudication: list["Adjudication"] = None,
        detail: list["Detail"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.itemSequence = itemSequence
        self.noteNumber = noteNumber or []
        self.adjudication = adjudication or []
        self.detail = detail or []

    @classmethod
    def from_dict(cls, data: dict) -> "ClaimResponse":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ClaimResponse":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class SubDetail(FhirBaseModel):
    """The third-tier service adjudications for payor added services.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept productOrService: Billing, service, product, or drug code
    :param CodeableConcept modifier: Service/Product billing modifiers
    :param Quantity quantity: Count of products or services
    :param Money unitPrice: Fee, charge or cost per item
    :param float factor: Price scaling factor
    :param Money net: Total item cost
    :param int noteNumber: Applicable note numbers
    :param Adjudication adjudication: Added items detail adjudication
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "productOrService": {"class_name": "CodeableConcept", "is_contained": False},
        "modifier": {"class_name": "CodeableConcept", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
        "unitPrice": {"class_name": "Money", "is_contained": False},
        "net": {"class_name": "Money", "is_contained": False},
        "adjudication": {"class_name": "Adjudication", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        productOrService: "CodeableConcept" = None,
        modifier: list["CodeableConcept"] = None,
        quantity: "Quantity" = None,
        unitPrice: "Money" = None,
        factor: "float" = None,
        net: "Money" = None,
        noteNumber: list["int"] = None,
        adjudication: list["Adjudication"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.productOrService = productOrService
        self.modifier = modifier or []
        self.quantity = quantity
        self.unitPrice = unitPrice
        self.factor = factor
        self.net = net
        self.noteNumber = noteNumber or []
        self.adjudication = adjudication or []

    @classmethod
    def from_dict(cls, data: dict) -> "ClaimResponse":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ClaimResponse":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Detail(FhirBaseModel):
    """The second-tier service adjudications for payor added services.:param int detailSequence: Detail sequence number
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept productOrService: Billing, service, product, or drug code
    :param CodeableConcept modifier: Service/Product billing modifiers
    :param Quantity quantity: Count of products or services
    :param Money unitPrice: Fee, charge or cost per item
    :param float factor: Price scaling factor
    :param Money net: Total item cost
    :param int noteNumber: Applicable note numbers
    :param Adjudication adjudication: Added items detail adjudication
    :param SubDetail subDetail: Insurer added line items
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "productOrService": {"class_name": "CodeableConcept", "is_contained": False},
        "modifier": {"class_name": "CodeableConcept", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
        "unitPrice": {"class_name": "Money", "is_contained": False},
        "net": {"class_name": "Money", "is_contained": False},
        "adjudication": {"class_name": "Adjudication", "is_contained": True},
        "subDetail": {"class_name": "SubDetail", "is_contained": True},
    }

    def __init__(
        self,
        detailSequence: list["int"] = None,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        productOrService: "CodeableConcept" = None,
        modifier: list["CodeableConcept"] = None,
        quantity: "Quantity" = None,
        unitPrice: "Money" = None,
        factor: "float" = None,
        net: "Money" = None,
        noteNumber: list["int"] = None,
        adjudication: list["Adjudication"] = None,
        subDetail: list["SubDetail"] = None,
    ):
        self.detailSequence = detailSequence or []
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.productOrService = productOrService
        self.modifier = modifier or []
        self.quantity = quantity
        self.unitPrice = unitPrice
        self.factor = factor
        self.net = net
        self.noteNumber = noteNumber or []
        self.adjudication = adjudication or []
        self.subDetail = subDetail or []

    @classmethod
    def from_dict(cls, data: dict) -> "ClaimResponse":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ClaimResponse":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class AddItem(FhirBaseModel):
    """The first-tier service adjudications for payor added product or service lines.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int itemSequence: Item sequence number
    :param int detailSequence: Detail sequence number
    :param int subdetailSequence: Subdetail sequence number
    :param Reference provider: Authorized providers
    :param CodeableConcept productOrService: Billing, service, product, or drug code
    :param CodeableConcept modifier: Service/Product billing modifiers
    :param CodeableConcept programCode: Program the product or service is provided under
    :param str servicedDate: Date or dates of service or product delivery
    :param Period servicedPeriod: Date or dates of service or product delivery
    :param CodeableConcept locationCodeableConcept: Place of service or where product was supplied
    :param Address locationAddress: Place of service or where product was supplied
    :param Reference locationReference: Place of service or where product was supplied
    :param Quantity quantity: Count of products or services
    :param Money unitPrice: Fee, charge or cost per item
    :param float factor: Price scaling factor
    :param Money net: Total item cost
    :param CodeableConcept bodySite: Anatomical location
    :param CodeableConcept subSite: Anatomical sub-location
    :param int noteNumber: Applicable note numbers
    :param Adjudication adjudication: Added items adjudication
    :param Detail detail: Insurer added line details
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "provider": {"class_name": "Reference", "is_contained": False},
        "productOrService": {"class_name": "CodeableConcept", "is_contained": False},
        "modifier": {"class_name": "CodeableConcept", "is_contained": False},
        "programCode": {"class_name": "CodeableConcept", "is_contained": False},
        "servicedPeriod": {"class_name": "Period", "is_contained": False},
        "locationCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "locationAddress": {"class_name": "Address", "is_contained": False},
        "locationReference": {"class_name": "Reference", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
        "unitPrice": {"class_name": "Money", "is_contained": False},
        "net": {"class_name": "Money", "is_contained": False},
        "bodySite": {"class_name": "CodeableConcept", "is_contained": False},
        "subSite": {"class_name": "CodeableConcept", "is_contained": False},
        "adjudication": {"class_name": "Adjudication", "is_contained": True},
        "detail": {"class_name": "Detail", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        itemSequence: list["int"] = None,
        detailSequence: list["int"] = None,
        subdetailSequence: list["int"] = None,
        provider: list["Reference"] = None,
        productOrService: "CodeableConcept" = None,
        modifier: list["CodeableConcept"] = None,
        programCode: list["CodeableConcept"] = None,
        servicedDate: "str" = None,
        servicedPeriod: "Period" = None,
        locationCodeableConcept: "CodeableConcept" = None,
        locationAddress: "Address" = None,
        locationReference: "Reference" = None,
        quantity: "Quantity" = None,
        unitPrice: "Money" = None,
        factor: "float" = None,
        net: "Money" = None,
        bodySite: "CodeableConcept" = None,
        subSite: list["CodeableConcept"] = None,
        noteNumber: list["int"] = None,
        adjudication: list["Adjudication"] = None,
        detail: list["Detail"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.itemSequence = itemSequence or []
        self.detailSequence = detailSequence or []
        self.subdetailSequence = subdetailSequence or []
        self.provider = provider or []
        self.productOrService = productOrService
        self.modifier = modifier or []
        self.programCode = programCode or []
        self.servicedDate = servicedDate
        self.servicedPeriod = servicedPeriod
        self.locationCodeableConcept = locationCodeableConcept
        self.locationAddress = locationAddress
        self.locationReference = locationReference
        self.quantity = quantity
        self.unitPrice = unitPrice
        self.factor = factor
        self.net = net
        self.bodySite = bodySite
        self.subSite = subSite or []
        self.noteNumber = noteNumber or []
        self.adjudication = adjudication or []
        self.detail = detail or []

    @classmethod
    def from_dict(cls, data: dict) -> "ClaimResponse":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ClaimResponse":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Total(FhirBaseModel):
    """Categorized monetary totals for the adjudication.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept category: Type of adjudication information
    :param Money amount: Financial total for the category
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "amount": {"class_name": "Money", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        category: "CodeableConcept" = None,
        amount: "Money" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.category = category
        self.amount = amount

    @classmethod
    def from_dict(cls, data: dict) -> "ClaimResponse":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ClaimResponse":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Payment(FhirBaseModel):
    """Payment details for the adjudication of the claim.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Partial or complete payment
    :param Money adjustment: Payment adjustment for non-claim issues
    :param CodeableConcept adjustmentReason: Explanation for the adjustment
    :param str date: Expected date of payment
    :param Money amount: Payable amount after adjustment
    :param Identifier identifier: Business identifier for the payment
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "adjustment": {"class_name": "Money", "is_contained": False},
        "adjustmentReason": {"class_name": "CodeableConcept", "is_contained": False},
        "amount": {"class_name": "Money", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        adjustment: "Money" = None,
        adjustmentReason: "CodeableConcept" = None,
        date: "str" = None,
        amount: "Money" = None,
        identifier: "Identifier" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.adjustment = adjustment
        self.adjustmentReason = adjustmentReason
        self.date = date
        self.amount = amount
        self.identifier = identifier

    @classmethod
    def from_dict(cls, data: dict) -> "ClaimResponse":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ClaimResponse":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ProcessNote(FhirBaseModel):
    """A note that describes or explains adjudication results in a human readable form.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int number: Note instance identifier
    :param str type: display | print | printoper
    :param str text: Note explanatory text
    :param CodeableConcept language: Language of the text
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "language": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        number: "int" = None,
        type: "str" = None,
        text: "str" = None,
        language: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.number = number
        self.type = type
        self.text = text
        self.language = language

    @classmethod
    def from_dict(cls, data: dict) -> "ClaimResponse":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ClaimResponse":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Insurance(FhirBaseModel):
    """Financial instruments for reimbursement for the health care products and services specified on the claim.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int sequence: Insurance instance identifier
    :param bool focal: Coverage to be used for adjudication
    :param Reference coverage: Insurance information
    :param str businessArrangement: Additional provider contract number
    :param Reference claimResponse: Adjudication results
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "coverage": {"class_name": "Reference", "is_contained": False},
        "claimResponse": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        sequence: "int" = None,
        focal: "bool" = None,
        coverage: "Reference" = None,
        businessArrangement: "str" = None,
        claimResponse: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.sequence = sequence
        self.focal = focal
        self.coverage = coverage
        self.businessArrangement = businessArrangement
        self.claimResponse = claimResponse

    @classmethod
    def from_dict(cls, data: dict) -> "ClaimResponse":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ClaimResponse":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Error(FhirBaseModel):
    """Errors encountered during the processing of the adjudication.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int itemSequence: Item sequence number
    :param int detailSequence: Detail sequence number
    :param int subDetailSequence: Subdetail sequence number
    :param CodeableConcept code: Error code detailing processing issues
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        itemSequence: "int" = None,
        detailSequence: "int" = None,
        subDetailSequence: "int" = None,
        code: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.itemSequence = itemSequence
        self.detailSequence = detailSequence
        self.subDetailSequence = subDetailSequence
        self.code = code

    @classmethod
    def from_dict(cls, data: dict) -> "ClaimResponse":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ClaimResponse":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ClaimResponse(DomainResource):
    """This resource provides the adjudication details from the processing of a Claim resource.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Business Identifier for a claim response
    :param str status: active | cancelled | draft | entered-in-error
    :param CodeableConcept type: More granular claim type
    :param CodeableConcept subType: More granular claim type
    :param str use: claim | preauthorization | predetermination
    :param Reference patient: The recipient of the products and services
    :param str created: Response creation date
    :param Reference insurer: Party responsible for reimbursement
    :param Reference requestor: Party responsible for the claim
    :param Reference request: Id of resource triggering adjudication
    :param str outcome: queued | complete | error | partial
    :param str disposition: Disposition Message
    :param str preAuthRef: Preauthorization reference
    :param Period preAuthPeriod: Preauthorization reference effective period
    :param CodeableConcept payeeType: Party to be paid any benefits payable
    :param Item item: Adjudication for claim line items
    :param AddItem addItem: Insurer added line items
    :param Adjudication adjudication: Header-level adjudication
    :param Total total: Adjudication totals
    :param Payment payment: Payment Details
    :param CodeableConcept fundsReserve: Funds reserved status
    :param CodeableConcept formCode: Printed form identifier
    :param Attachment form: Printed reference or actual form
    :param ProcessNote processNote: Note concerning adjudication
    :param Reference communicationRequest: Request for additional information
    :param Insurance insurance: Patient insurance information
    :param Error error: Processing errors
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "subType": {"class_name": "CodeableConcept", "is_contained": False},
        "patient": {"class_name": "Reference", "is_contained": False},
        "insurer": {"class_name": "Reference", "is_contained": False},
        "requestor": {"class_name": "Reference", "is_contained": False},
        "request": {"class_name": "Reference", "is_contained": False},
        "preAuthPeriod": {"class_name": "Period", "is_contained": False},
        "payeeType": {"class_name": "CodeableConcept", "is_contained": False},
        "item": {"class_name": "Item", "is_contained": True},
        "addItem": {"class_name": "AddItem", "is_contained": True},
        "adjudication": {"class_name": "Adjudication", "is_contained": True},
        "total": {"class_name": "Total", "is_contained": True},
        "payment": {"class_name": "Payment", "is_contained": True},
        "fundsReserve": {"class_name": "CodeableConcept", "is_contained": False},
        "formCode": {"class_name": "CodeableConcept", "is_contained": False},
        "form": {"class_name": "Attachment", "is_contained": False},
        "processNote": {"class_name": "ProcessNote", "is_contained": True},
        "communicationRequest": {"class_name": "Reference", "is_contained": False},
        "insurance": {"class_name": "Insurance", "is_contained": True},
        "error": {"class_name": "Error", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        status: "str" = None,
        type: "CodeableConcept" = None,
        subType: "CodeableConcept" = None,
        use: "str" = None,
        patient: "Reference" = None,
        created: "str" = None,
        insurer: "Reference" = None,
        requestor: "Reference" = None,
        request: "Reference" = None,
        outcome: "str" = None,
        disposition: "str" = None,
        preAuthRef: "str" = None,
        preAuthPeriod: "Period" = None,
        payeeType: "CodeableConcept" = None,
        item: list["Item"] = None,
        addItem: list["AddItem"] = None,
        adjudication: list["Adjudication"] = None,
        total: list["Total"] = None,
        payment: "Payment" = None,
        fundsReserve: "CodeableConcept" = None,
        formCode: "CodeableConcept" = None,
        form: "Attachment" = None,
        processNote: list["ProcessNote"] = None,
        communicationRequest: list["Reference"] = None,
        insurance: list["Insurance"] = None,
        error: list["Error"] = None,
    ):

        self.resourceType = "ClaimResponse"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.status = status
        self.type = type
        self.subType = subType
        self.use = use
        self.patient = patient
        self.created = created
        self.insurer = insurer
        self.requestor = requestor
        self.request = request
        self.outcome = outcome
        self.disposition = disposition
        self.preAuthRef = preAuthRef
        self.preAuthPeriod = preAuthPeriod
        self.payeeType = payeeType
        self.item = item or []
        self.addItem = addItem or []
        self.adjudication = adjudication or []
        self.total = total or []
        self.payment = payment
        self.fundsReserve = fundsReserve
        self.formCode = formCode
        self.form = form
        self.processNote = processNote or []
        self.communicationRequest = communicationRequest or []
        self.insurance = insurance or []
        self.error = error or []

    @classmethod
    def from_dict(cls, data: dict) -> "ClaimResponse":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ClaimResponse":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for ContactPoint. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Period import *


class ContactPoint(FhirBaseModel):
    """ContactPoint Type: Details for all kinds of technology mediated contact points for a person or organization, including telephone, email, etc.
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param str system: phone | fax | email | pager | url | sms | other
    :param str value: The actual contact point details
    :param str use: home | work | temp | old | mobile - purpose of this contact point
    :param int rank: Specify preferred order of use (1 = highest)
    :param Period period: Time period when the contact point was/is in use
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        system: "str" = None,
        value: "str" = None,
        use: "str" = None,
        rank: "int" = None,
        period: "Period" = None,
    ):

        self.id = id
        self.extension = extension or []
        self.system = system
        self.value = value
        self.use = use
        self.rank = rank
        self.period = period

    @classmethod
    def from_dict(cls, data: dict) -> "ContactPoint":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ContactPoint":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Identifier. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Period import *
from fhirmodels.R4.Reference import *


class Identifier(FhirBaseModel):
    """Base StructureDefinition for Identifier Type: An identifier - identifies some entity uniquely and unambiguously. Typically this is used for business identifiers.
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param str use: usual | official | temp | secondary | old (If known)
    :param CodeableConcept type: Description of identifier
    :param str system: The namespace for the identifier value
    :param str value: The value that is unique
    :param Period period: Time period when id is/was valid for use
    :param Reference assigner: Organization that issued id (may be just text)
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
        "assigner": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        use: "str" = None,
        type: "CodeableConcept" = None,
        system: "str" = None,
        value: "str" = None,
        period: "Period" = None,
        assigner: "Reference" = None,
    ):

        self.id = id
        self.extension = extension or []
        self.use = use
        self.type = type
        self.system = system
        self.value = value
        self.period = period
        self.assigner = assigner

    @classmethod
    def from_dict(cls, data: dict) -> "Identifier":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Identifier":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for UsageContext. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.Coding import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Quantity import *
from fhirmodels.R4.Range import *
from fhirmodels.R4.Reference import *


class UsageContext(FhirBaseModel):
    """Base StructureDefinition for UsageContext Type: Specifies clinical/business/etc. metadata that can be used to retrieve, index and/or categorize an artifact. This metadata can either be specific to the applicable population (e.g., age category, DRG) or the specific context of care (e.g., venue, care setting, provider of care).
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Coding code: Type of context being specified
    :param CodeableConcept valueCodeableConcept: Value that defines the context
    :param Quantity valueQuantity: Value that defines the context
    :param Range valueRange: Value that defines the context
    :param Reference valueReference: Value that defines the context
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "Coding", "is_contained": False},
        "valueCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "valueQuantity": {"class_name": "Quantity", "is_contained": False},
        "valueRange": {"class_name": "Range", "is_contained": False},
        "valueReference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        code: "Coding" = None,
        valueCodeableConcept: "CodeableConcept" = None,
        valueQuantity: "Quantity" = None,
        valueRange: "Range" = None,
        valueReference: "Reference" = None,
    ):

        self.id = id
        self.extension = extension or []
        self.code = code
        self.valueCodeableConcept = valueCodeableConcept
        self.valueQuantity = valueQuantity
        self.valueRange = valueRange
        self.valueReference = valueReference

    @classmethod
    def from_dict(cls, data: dict) -> "UsageContext":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "UsageContext":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Definition. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.ContactDetail import *
from fhirmodels.R4.Identifier import *
from fhirmodels.R4.Period import *
from fhirmodels.R4.Reference import *
from fhirmodels.R4.UsageContext import *


class Definition(FhirBaseModel):
    """Logical Model: A pattern to be followed by resources that represent a specific proposal, plan and/or order for some sort of action or service.
    :param str url: Logical canonical URL to reference this {{title}} (globally unique)
    :param Identifier identifier: Business Identifier for {{title}}
    :param str version: Business version of the {{title}}
    :param str title: Name for this {{title}} (Human friendly)
    :param str derivedFromCanonical: Based on FHIR protocol or definition
    :param str derivedFromUri: Based on external protocol or definition
    :param str partOf: Part of referenced definition
    :param str replaces: Request(s) replaced by this request
    :param str status: draft | active | retired | unknown
    :param bool experimental: If for testing purposes, not real usage
    :param CodeableConcept subjectCodeableConcept: Type of individual the defined service is for
    :param Reference subjectReference: Type of individual the defined service is for
    :param str date: Date status first applied
    :param Reference publisher: The name of the individual or organization that published the {{title}}
    :param ContactDetail contact: Contact details for the publisher
    :param str description: Natural language description of the {{title}}
    :param UsageContext useContext: Content intends to support these contexts
    :param CodeableConcept jurisdiction: Intended jurisdiction for {{title}} (if applicable)
    :param str purpose: Why this {{title}} is defined
    :param str copyright: Use and/or publishing restrictions
    :param str approvalDate: When {{title}} approved by publisher
    :param str lastReviewDate: Last review date for the {{title}}
    :param Period effectivePeriod: The effective date range for the {{title}}
    :param CodeableConcept performerType: Desired kind of service performer
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "subjectCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "subjectReference": {"class_name": "Reference", "is_contained": False},
        "publisher": {"class_name": "Reference", "is_contained": False},
        "contact": {"class_name": "ContactDetail", "is_contained": False},
        "useContext": {"class_name": "UsageContext", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
        "effectivePeriod": {"class_name": "Period", "is_contained": False},
        "performerType": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        url: "str" = None,
        identifier: "Identifier" = None,
        version: "str" = None,
        title: "str" = None,
        derivedFromCanonical: list["str"] = None,
        derivedFromUri: list["str"] = None,
        partOf: list["str"] = None,
        replaces: list["str"] = None,
        status: "str" = None,
        experimental: "bool" = None,
        subjectCodeableConcept: "CodeableConcept" = None,
        subjectReference: "Reference" = None,
        date: "str" = None,
        publisher: "Reference" = None,
        contact: list["ContactDetail"] = None,
        description: "str" = None,
        useContext: list["UsageContext"] = None,
        jurisdiction: list["CodeableConcept"] = None,
        purpose: "str" = None,
        copyright: "str" = None,
        approvalDate: "str" = None,
        lastReviewDate: "str" = None,
        effectivePeriod: "Period" = None,
        performerType: "CodeableConcept" = None,
    ):

        self.url = url
        self.identifier = identifier
        self.version = version
        self.title = title
        self.derivedFromCanonical = derivedFromCanonical or []
        self.derivedFromUri = derivedFromUri or []
        self.partOf = partOf or []
        self.replaces = replaces or []
        self.status = status
        self.experimental = experimental
        self.subjectCodeableConcept = subjectCodeableConcept
        self.subjectReference = subjectReference
        self.date = date
        self.publisher = publisher
        self.contact = contact or []
        self.description = description
        self.useContext = useContext or []
        self.jurisdiction = jurisdiction or []
        self.purpose = purpose
        self.copyright = copyright
        self.approvalDate = approvalDate
        self.lastReviewDate = lastReviewDate
        self.effectivePeriod = effectivePeriod
        self.performerType = performerType

    @classmethod
    def from_dict(cls, data: dict) -> "Definition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Definition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Age. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R4B.Extension import *


class Age(FhirBaseModel):
    """Base StructureDefinition for Age Type: A duration of time during which an organism (or a process) has existed.
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param float value: Numerical value (with implicit precision)
    :param str comparator: < | <= | >= | > - how to understand the value
    :param str unit: Unit representation
    :param str system: System that defines coded unit form
    :param str code: Coded form of the unit
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        value: "float" = None,
        comparator: "str" = None,
        unit: "str" = None,
        system: "str" = None,
        code: "str" = None,
    ):

        self.id = id
        self.extension = extension or []
        self.value = value
        self.comparator = comparator
        self.unit = unit
        self.system = system
        self.code = code

    @classmethod
    def from_dict(cls, data: dict) -> "Age":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Age":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Definition. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.Coding import *
from fhirmodels.R5.ContactDetail import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.UsageContext import *


class Definition(FhirBaseModel):
    """Logical Model: A pattern to be followed by resources that represent a specific proposal, plan and/or order for some sort of action or service.
    :param str url: Canonical identifier for this {{title}}, represented as an absolute URI (globally unique)
    :param Identifier identifier: Business identifier for {{title}}
    :param str version: Business version of the {{title}}
    :param str versionAlgorithmString: How to compare versions
    :param Coding versionAlgorithmCoding: How to compare versions
    :param str name: Name for this {{title}} (computer friendly)
    :param str title: Name for this {{title}} (human friendly)
    :param str derivedFromCanonical: Based on FHIR protocol or definition
    :param str derivedFromUri: Based on external protocol or definition
    :param str partOf: Part of referenced definition
    :param str status: draft | active | retired | unknown
    :param bool experimental: For testing purposes, not real usage
    :param CodeableReference subject: Type of individual the defined service is for
    :param str date: Date last changed
    :param str publisher: Name of the publisher/steward (organization or individual)
    :param ContactDetail contact: Contact details for the publisher
    :param str description: Natural language description of the {{title}}
    :param UsageContext useContext: The context that the content is intended to support
    :param CodeableConcept jurisdiction: Intended jurisdiction for {{title}} (if applicable)
    :param str purpose: Why this {{title}} is defined
    :param str copyright: Use and/or publishing restrictions
    :param str copyrightLabel: Copyright holder and year(s)
    :param str approvalDate: When the {{title}} was approved by publisher
    :param str lastReviewDate: When the {{title}} was last reviewed
    :param Period effectivePeriod: When the {{title}} is expected to be used
    :param CodeableConcept topic: Descriptive topics related to the content of the {{title}}. Topics provide a high-level categorization as well as keywords for the {{title}} that can be useful for filtering and searching
    :param CodeableConcept performerType: Desired kind of service performer
    :param CodeableConcept code: Service to be done
    :param CodeableReference product: Product to use/manipulate
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "versionAlgorithmCoding": {"class_name": "Coding", "is_contained": False},
        "subject": {"class_name": "CodeableReference", "is_contained": False},
        "contact": {"class_name": "ContactDetail", "is_contained": False},
        "useContext": {"class_name": "UsageContext", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
        "effectivePeriod": {"class_name": "Period", "is_contained": False},
        "topic": {"class_name": "CodeableConcept", "is_contained": False},
        "performerType": {"class_name": "CodeableConcept", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "product": {"class_name": "CodeableReference", "is_contained": False},
    }

    def __init__(
        self,
        url: "str" = None,
        identifier: list["Identifier"] = None,
        version: "str" = None,
        versionAlgorithmString: "str" = None,
        versionAlgorithmCoding: "Coding" = None,
        name: "str" = None,
        title: "str" = None,
        derivedFromCanonical: list["str"] = None,
        derivedFromUri: list["str"] = None,
        partOf: list["str"] = None,
        status: "str" = None,
        experimental: "bool" = None,
        subject: list["CodeableReference"] = None,
        date: "str" = None,
        publisher: "str" = None,
        contact: list["ContactDetail"] = None,
        description: "str" = None,
        useContext: list["UsageContext"] = None,
        jurisdiction: list["CodeableConcept"] = None,
        purpose: "str" = None,
        copyright: "str" = None,
        copyrightLabel: "str" = None,
        approvalDate: "str" = None,
        lastReviewDate: "str" = None,
        effectivePeriod: "Period" = None,
        topic: list["CodeableConcept"] = None,
        performerType: "CodeableConcept" = None,
        code: "CodeableConcept" = None,
        product: "CodeableReference" = None,
    ):

        self.url = url
        self.identifier = identifier or []
        self.version = version
        self.versionAlgorithmString = versionAlgorithmString
        self.versionAlgorithmCoding = versionAlgorithmCoding
        self.name = name
        self.title = title
        self.derivedFromCanonical = derivedFromCanonical or []
        self.derivedFromUri = derivedFromUri or []
        self.partOf = partOf or []
        self.status = status
        self.experimental = experimental
        self.subject = subject or []
        self.date = date
        self.publisher = publisher
        self.contact = contact or []
        self.description = description
        self.useContext = useContext or []
        self.jurisdiction = jurisdiction or []
        self.purpose = purpose
        self.copyright = copyright
        self.copyrightLabel = copyrightLabel
        self.approvalDate = approvalDate
        self.lastReviewDate = lastReviewDate
        self.effectivePeriod = effectivePeriod
        self.topic = topic or []
        self.performerType = performerType
        self.code = code
        self.product = product

    @classmethod
    def from_dict(cls, data: dict) -> "Definition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Definition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for HealthcareService. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Attachment import *
from fhirmodels.R5.Availability import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.ExtendedContactDetail import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class Eligibility(FhirBaseModel):
    """Does this service have specific eligibility requirements that need to be met in order to use the service?:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept code: Coded value for the eligibility
    :param str comment: Describes the eligibility conditions for the service
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "CodeableConcept" = None,
        comment: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.comment = comment

    @classmethod
    def from_dict(cls, data: dict) -> "HealthcareService":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "HealthcareService":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class HealthcareService(DomainResource):
    """The details of a healthcare service available at a location or in a catalog.  In the case where there is a hierarchy of services (for example, Lab -> Pathology -> Wound Cultures), this can be represented using a set of linked HealthcareServices.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: External identifiers for this item
    :param bool active: Whether this HealthcareService record is in active use
    :param Reference providedBy: Organization that provides this service
    :param Reference offeredIn: The service within which this service is offered
    :param CodeableConcept category: Broad category of service being performed or delivered
    :param CodeableConcept type: Type of service that may be delivered or performed
    :param CodeableConcept specialty: Specialties handled by the HealthcareService
    :param Reference location: Location(s) where service may be provided
    :param str name: Description of service as presented to a consumer while searching
    :param str comment: Additional description and/or any specific issues not covered elsewhere
    :param str extraDetails: Extra details about the service that can't be placed in the other fields
    :param Attachment photo: Facilitates quick identification of the service
    :param ExtendedContactDetail contact: Official contact details for the HealthcareService
    :param Reference coverageArea: Location(s) service is intended for/available to
    :param CodeableConcept serviceProvisionCode: Conditions under which service is available/offered
    :param Eligibility eligibility: Specific eligibility requirements required to use the service
    :param CodeableConcept program: Programs that this service is applicable to
    :param CodeableConcept characteristic: Collection of characteristics (attributes)
    :param CodeableConcept communication: The language that this service is offered in
    :param CodeableConcept referralMethod: Ways that the service accepts referrals
    :param bool appointmentRequired: If an appointment is required for access to this service
    :param Availability availability: Times the healthcare service is available (including exceptions)
    :param Reference endpoint: Technical endpoints providing access to electronic services operated for the healthcare service
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "providedBy": {"class_name": "Reference", "is_contained": False},
        "offeredIn": {"class_name": "Reference", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "specialty": {"class_name": "CodeableConcept", "is_contained": False},
        "location": {"class_name": "Reference", "is_contained": False},
        "photo": {"class_name": "Attachment", "is_contained": False},
        "contact": {"class_name": "ExtendedContactDetail", "is_contained": False},
        "coverageArea": {"class_name": "Reference", "is_contained": False},
        "serviceProvisionCode": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "eligibility": {"class_name": "Eligibility", "is_contained": True},
        "program": {"class_name": "CodeableConcept", "is_contained": False},
        "characteristic": {"class_name": "CodeableConcept", "is_contained": False},
        "communication": {"class_name": "CodeableConcept", "is_contained": False},
        "referralMethod": {"class_name": "CodeableConcept", "is_contained": False},
        "availability": {"class_name": "Availability", "is_contained": False},
        "endpoint": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        active: "bool" = None,
        providedBy: "Reference" = None,
        offeredIn: list["Reference"] = None,
        category: list["CodeableConcept"] = None,
        type: list["CodeableConcept"] = None,
        specialty: list["CodeableConcept"] = None,
        location: list["Reference"] = None,
        name: "str" = None,
        comment: "str" = None,
        extraDetails: "str" = None,
        photo: "Attachment" = None,
        contact: list["ExtendedContactDetail"] = None,
        coverageArea: list["Reference"] = None,
        serviceProvisionCode: list["CodeableConcept"] = None,
        eligibility: list["Eligibility"] = None,
        program: list["CodeableConcept"] = None,
        characteristic: list["CodeableConcept"] = None,
        communication: list["CodeableConcept"] = None,
        referralMethod: list["CodeableConcept"] = None,
        appointmentRequired: "bool" = None,
        availability: list["Availability"] = None,
        endpoint: list["Reference"] = None,
    ):

        self.resourceType = "HealthcareService"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.active = active
        self.providedBy = providedBy
        self.offeredIn = offeredIn or []
        self.category = category or []
        self.type = type or []
        self.specialty = specialty or []
        self.location = location or []
        self.name = name
        self.comment = comment
        self.extraDetails = extraDetails
        self.photo = photo
        self.contact = contact or []
        self.coverageArea = coverageArea or []
        self.serviceProvisionCode = serviceProvisionCode or []
        self.eligibility = eligibility or []
        self.program = program or []
        self.characteristic = characteristic or []
        self.communication = communication or []
        self.referralMethod = referralMethod or []
        self.appointmentRequired = appointmentRequired
        self.availability = availability or []
        self.endpoint = endpoint or []

    @classmethod
    def from_dict(cls, data: dict) -> "HealthcareService":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "HealthcareService":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for MedicationKnowledge. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.BackboneElement import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Dosage import *
from fhirmodels.R4.Duration import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Money import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Quantity import *
from fhirmodels.R4.Ratio import *
from fhirmodels.R4.Reference import *
from fhirmodels.R4.Resource import *


class RelatedMedicationKnowledge(FhirBaseModel):
    """Associated or related knowledge about a medication.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Category of medicationKnowledge
    :param Reference reference: Associated documentation about the associated medication knowledge
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "reference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        reference: list["Reference"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.reference = reference or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Monograph(FhirBaseModel):
    """Associated documentation about the medication.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: The category of medication document
    :param Reference source: Associated documentation about the medication
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "source": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        source: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.source = source

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Ingredient(FhirBaseModel):
    """Identifies a particular constituent of interest in the product.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept itemCodeableConcept: Medication(s) or substance(s) contained in the medication
    :param Reference itemReference: Medication(s) or substance(s) contained in the medication
    :param bool isActive: Active ingredient indicator
    :param Ratio strength: Quantity of ingredient present
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "itemCodeableConcept": {"class_name": "CodeableConcept", "is_contained": False},
        "itemReference": {"class_name": "Reference", "is_contained": False},
        "strength": {"class_name": "Ratio", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        itemCodeableConcept: "CodeableConcept" = None,
        itemReference: "Reference" = None,
        isActive: "bool" = None,
        strength: "Ratio" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.itemCodeableConcept = itemCodeableConcept
        self.itemReference = itemReference
        self.isActive = isActive
        self.strength = strength

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Cost(FhirBaseModel):
    """The price of the medication.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: The category of the cost information
    :param str source: The source or owner for the price information
    :param Money cost: The price of the medication
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "cost": {"class_name": "Money", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        source: "str" = None,
        cost: "Money" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.source = source
        self.cost = cost

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class MonitoringProgram(FhirBaseModel):
    """The program under which the medication is reviewed.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Type of program under which the medication is monitored
    :param str name: Name of the reviewing program
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        name: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.name = name

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Dosage(FhirBaseModel):
    """Dosage for the medication for the specific guidelines.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Type of dosage
    :param Dosage dosage: Dosage for the medication for the specific guidelines
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "dosage": {"class_name": "Dosage", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        dosage: list["Dosage"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.dosage = dosage or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class PatientCharacteristics(FhirBaseModel):
    """Characteristics of the patient that are relevant to the administration guidelines (for example, height, weight, gender, etc.).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept characteristicCodeableConcept: Specific characteristic that is relevant to the administration guideline
    :param Quantity characteristicQuantity: Specific characteristic that is relevant to the administration guideline
    :param str value: The specific characteristic
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "characteristicCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "characteristicQuantity": {"class_name": "Quantity", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        characteristicCodeableConcept: "CodeableConcept" = None,
        characteristicQuantity: "Quantity" = None,
        value: list["str"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.characteristicCodeableConcept = characteristicCodeableConcept
        self.characteristicQuantity = characteristicQuantity
        self.value = value or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class AdministrationGuidelines(FhirBaseModel):
    """Guidelines for the administration of the medication.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Dosage dosage: Dosage for the medication for the specific guidelines
    :param CodeableConcept indicationCodeableConcept: Indication for use that apply to the specific administration guidelines
    :param Reference indicationReference: Indication for use that apply to the specific administration guidelines
    :param PatientCharacteristics patientCharacteristics: Characteristics of the patient that are relevant to the administration guidelines
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "dosage": {"class_name": "Dosage", "is_contained": True},
        "indicationCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "indicationReference": {"class_name": "Reference", "is_contained": False},
        "patientCharacteristics": {
            "class_name": "PatientCharacteristics",
            "is_contained": True,
        },
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        dosage: list["Dosage"] = None,
        indicationCodeableConcept: "CodeableConcept" = None,
        indicationReference: "Reference" = None,
        patientCharacteristics: list["PatientCharacteristics"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.dosage = dosage or []
        self.indicationCodeableConcept = indicationCodeableConcept
        self.indicationReference = indicationReference
        self.patientCharacteristics = patientCharacteristics or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class MedicineClassification(FhirBaseModel):
    """Categorization of the medication within a formulary or classification system.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: The type of category for the medication (for example, therapeutic classification, therapeutic sub-classification)
    :param CodeableConcept classification: Specific category assigned to the medication
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "classification": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        classification: list["CodeableConcept"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.classification = classification or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Packaging(FhirBaseModel):
    """Information that only applies to packages (not products).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: A code that defines the specific type of packaging that the medication can be found in
    :param Quantity quantity: The number of product units the package would contain if fully loaded
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        quantity: "Quantity" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.quantity = quantity

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class DrugCharacteristic(FhirBaseModel):
    """Specifies descriptive properties of the medicine, such as color, shape, imprints, etc.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Code specifying the type of characteristic of medication
    :param CodeableConcept valueCodeableConcept: Description of the characteristic
    :param str valueString: Description of the characteristic
    :param Quantity valueQuantity: Description of the characteristic
    :param str valueBase64Binary: Description of the characteristic
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "valueCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "valueQuantity": {"class_name": "Quantity", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        valueCodeableConcept: "CodeableConcept" = None,
        valueString: "str" = None,
        valueQuantity: "Quantity" = None,
        valueBase64Binary: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.valueCodeableConcept = valueCodeableConcept
        self.valueString = valueString
        self.valueQuantity = valueQuantity
        self.valueBase64Binary = valueBase64Binary

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Substitution(FhirBaseModel):
    """Specifies if changes are allowed when dispensing a medication from a regulatory perspective.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Specifies the type of substitution allowed
    :param bool allowed: Specifies if regulation allows for changes in the medication when dispensing
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        allowed: "bool" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.allowed = allowed

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Schedule(FhirBaseModel):
    """Specifies the schedule of a medication in jurisdiction.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept schedule: Specifies the specific drug schedule
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "schedule": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        schedule: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.schedule = schedule

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class MaxDispense(FhirBaseModel):
    """The maximum number of units of the medication that can be dispensed in a period.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Quantity quantity: The maximum number of units of the medication that can be dispensed
    :param Duration period: The period that applies to the maximum number of units
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
        "period": {"class_name": "Duration", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        quantity: "Quantity" = None,
        period: "Duration" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.quantity = quantity
        self.period = period

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Regulatory(FhirBaseModel):
    """Regulatory information about a medication.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference regulatoryAuthority: Specifies the authority of the regulation
    :param Substitution substitution: Specifies if changes are allowed when dispensing a medication from a regulatory perspective
    :param Schedule schedule: Specifies the schedule of a medication in jurisdiction
    :param MaxDispense maxDispense: The maximum number of units of the medication that can be dispensed in a period
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "regulatoryAuthority": {"class_name": "Reference", "is_contained": False},
        "substitution": {"class_name": "Substitution", "is_contained": True},
        "schedule": {"class_name": "Schedule", "is_contained": True},
        "maxDispense": {"class_name": "MaxDispense", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        regulatoryAuthority: "Reference" = None,
        substitution: list["Substitution"] = None,
        schedule: list["Schedule"] = None,
        maxDispense: "MaxDispense" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.regulatoryAuthority = regulatoryAuthority
        self.substitution = substitution or []
        self.schedule = schedule or []
        self.maxDispense = maxDispense

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Kinetics(FhirBaseModel):
    """The time course of drug absorption, distribution, metabolism and excretion of a medication from the body.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Quantity areaUnderCurve: The drug concentration measured at certain discrete points in time
    :param Quantity lethalDose50: The median lethal dose of a drug
    :param Duration halfLifePeriod: Time required for concentration in the body to decrease by half
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "areaUnderCurve": {"class_name": "Quantity", "is_contained": False},
        "lethalDose50": {"class_name": "Quantity", "is_contained": False},
        "halfLifePeriod": {"class_name": "Duration", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        areaUnderCurve: list["Quantity"] = None,
        lethalDose50: list["Quantity"] = None,
        halfLifePeriod: "Duration" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.areaUnderCurve = areaUnderCurve or []
        self.lethalDose50 = lethalDose50 or []
        self.halfLifePeriod = halfLifePeriod

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class MedicationKnowledge(DomainResource):
    """Information about a medication that is used to support knowledge.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param CodeableConcept code: Code that identifies this medication
    :param str status: active | inactive | entered-in-error
    :param Reference manufacturer: Manufacturer of the item
    :param CodeableConcept doseForm: powder | tablets | capsule +
    :param Quantity amount: Amount of drug in package
    :param str synonym: Additional names for a medication
    :param RelatedMedicationKnowledge relatedMedicationKnowledge: Associated or related medication information
    :param Reference associatedMedication: A medication resource that is associated with this medication
    :param CodeableConcept productType: Category of the medication or product
    :param Monograph monograph: Associated documentation about the medication
    :param Ingredient ingredient: Active or inactive ingredient
    :param str preparationInstruction: The instructions for preparing the medication
    :param CodeableConcept intendedRoute: The intended or approved route of administration
    :param Cost cost: The pricing of the medication
    :param MonitoringProgram monitoringProgram: Program under which a medication is reviewed
    :param AdministrationGuidelines administrationGuidelines: Guidelines for administration of the medication
    :param MedicineClassification medicineClassification: Categorization of the medication within a formulary or classification system
    :param Packaging packaging: Details about packaged medications
    :param DrugCharacteristic drugCharacteristic: Specifies descriptive properties of the medicine
    :param Reference contraindication: Potential clinical issue with or between medication(s)
    :param Regulatory regulatory: Regulatory information about a medication
    :param Kinetics kinetics: The time course of drug absorption, distribution, metabolism and excretion of a medication from the body
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "manufacturer": {"class_name": "Reference", "is_contained": False},
        "doseForm": {"class_name": "CodeableConcept", "is_contained": False},
        "amount": {"class_name": "Quantity", "is_contained": False},
        "relatedMedicationKnowledge": {
            "class_name": "RelatedMedicationKnowledge",
            "is_contained": True,
        },
        "associatedMedication": {"class_name": "Reference", "is_contained": False},
        "productType": {"class_name": "CodeableConcept", "is_contained": False},
        "monograph": {"class_name": "Monograph", "is_contained": True},
        "ingredient": {"class_name": "Ingredient", "is_contained": True},
        "intendedRoute": {"class_name": "CodeableConcept", "is_contained": False},
        "cost": {"class_name": "Cost", "is_contained": True},
        "monitoringProgram": {"class_name": "MonitoringProgram", "is_contained": True},
        "administrationGuidelines": {
            "class_name": "AdministrationGuidelines",
            "is_contained": True,
        },
        "medicineClassification": {
            "class_name": "MedicineClassification",
            "is_contained": True,
        },
        "packaging": {"class_name": "Packaging", "is_contained": True},
        "drugCharacteristic": {
            "class_name": "DrugCharacteristic",
            "is_contained": True,
        },
        "contraindication": {"class_name": "Reference", "is_contained": False},
        "regulatory": {"class_name": "Regulatory", "is_contained": True},
        "kinetics": {"class_name": "Kinetics", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "CodeableConcept" = None,
        status: "str" = None,
        manufacturer: "Reference" = None,
        doseForm: "CodeableConcept" = None,
        amount: "Quantity" = None,
        synonym: list["str"] = None,
        relatedMedicationKnowledge: list["RelatedMedicationKnowledge"] = None,
        associatedMedication: list["Reference"] = None,
        productType: list["CodeableConcept"] = None,
        monograph: list["Monograph"] = None,
        ingredient: list["Ingredient"] = None,
        preparationInstruction: "str" = None,
        intendedRoute: list["CodeableConcept"] = None,
        cost: list["Cost"] = None,
        monitoringProgram: list["MonitoringProgram"] = None,
        administrationGuidelines: list["AdministrationGuidelines"] = None,
        medicineClassification: list["MedicineClassification"] = None,
        packaging: "Packaging" = None,
        drugCharacteristic: list["DrugCharacteristic"] = None,
        contraindication: list["Reference"] = None,
        regulatory: list["Regulatory"] = None,
        kinetics: list["Kinetics"] = None,
    ):

        self.resourceType = "MedicationKnowledge"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.status = status
        self.manufacturer = manufacturer
        self.doseForm = doseForm
        self.amount = amount
        self.synonym = synonym or []
        self.relatedMedicationKnowledge = relatedMedicationKnowledge or []
        self.associatedMedication = associatedMedication or []
        self.productType = productType or []
        self.monograph = monograph or []
        self.ingredient = ingredient or []
        self.preparationInstruction = preparationInstruction
        self.intendedRoute = intendedRoute or []
        self.cost = cost or []
        self.monitoringProgram = monitoringProgram or []
        self.administrationGuidelines = administrationGuidelines or []
        self.medicineClassification = medicineClassification or []
        self.packaging = packaging
        self.drugCharacteristic = drugCharacteristic or []
        self.contraindication = contraindication or []
        self.regulatory = regulatory or []
        self.kinetics = kinetics or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationKnowledge":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationKnowledge":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for ServiceRequest. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.Annotation import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Identifier import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Period import *
from fhirmodels.R4.Quantity import *
from fhirmodels.R4.Range import *
from fhirmodels.R4.Ratio import *
from fhirmodels.R4.Reference import *
from fhirmodels.R4.Resource import *
from fhirmodels.R4.Timing import *


class ServiceRequest(DomainResource):
    """A record of a request for service such as diagnostic investigations, treatments, or operations to be performed.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Identifiers assigned to this order
    :param str instantiatesCanonical: Instantiates FHIR protocol or definition
    :param str instantiatesUri: Instantiates external protocol or definition
    :param Reference basedOn: What request fulfills
    :param Reference replaces: What request replaces
    :param Identifier requisition: Composite Request ID
    :param str status: draft | active | on-hold | revoked | completed | entered-in-error | unknown
    :param str intent: proposal | plan | directive | order | original-order | reflex-order | filler-order | instance-order | option
    :param CodeableConcept category: Classification of service
    :param str priority: routine | urgent | asap | stat
    :param bool doNotPerform: True if service/procedure should not be performed
    :param CodeableConcept code: What is being requested/ordered
    :param CodeableConcept orderDetail: Additional order information
    :param Quantity quantityQuantity: Service amount
    :param Ratio quantityRatio: Service amount
    :param Range quantityRange: Service amount
    :param Reference subject: Individual or Entity the service is ordered for
    :param Reference encounter: Encounter in which the request was created
    :param str occurrenceDateTime: When service should occur
    :param Period occurrencePeriod: When service should occur
    :param Timing occurrenceTiming: When service should occur
    :param bool asNeededBoolean: Preconditions for service
    :param CodeableConcept asNeededCodeableConcept: Preconditions for service
    :param str authoredOn: Date request signed
    :param Reference requester: Who/what is requesting service
    :param CodeableConcept performerType: Performer role
    :param Reference performer: Requested performer
    :param CodeableConcept locationCode: Requested location
    :param Reference locationReference: Requested location
    :param CodeableConcept reasonCode: Explanation/Justification for procedure or service
    :param Reference reasonReference: Explanation/Justification for service or service
    :param Reference insurance: Associated insurance coverage
    :param Reference supportingInfo: Additional clinical information
    :param Reference specimen: Procedure Samples
    :param CodeableConcept bodySite: Location on Body
    :param Annotation note: Comments
    :param str patientInstruction: Patient or consumer-oriented instructions
    :param Reference relevantHistory: Request provenance
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "basedOn": {"class_name": "Reference", "is_contained": False},
        "replaces": {"class_name": "Reference", "is_contained": False},
        "requisition": {"class_name": "Identifier", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "orderDetail": {"class_name": "CodeableConcept", "is_contained": False},
        "quantityQuantity": {"class_name": "Quantity", "is_contained": False},
        "quantityRatio": {"class_name": "Ratio", "is_contained": False},
        "quantityRange": {"class_name": "Range", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "encounter": {"class_name": "Reference", "is_contained": False},
        "occurrencePeriod": {"class_name": "Period", "is_contained": False},
        "occurrenceTiming": {"class_name": "Timing", "is_contained": False},
        "asNeededCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "requester": {"class_name": "Reference", "is_contained": False},
        "performerType": {"class_name": "CodeableConcept", "is_contained": False},
        "performer": {"class_name": "Reference", "is_contained": False},
        "locationCode": {"class_name": "CodeableConcept", "is_contained": False},
        "locationReference": {"class_name": "Reference", "is_contained": False},
        "reasonCode": {"class_name": "CodeableConcept", "is_contained": False},
        "reasonReference": {"class_name": "Reference", "is_contained": False},
        "insurance": {"class_name": "Reference", "is_contained": False},
        "supportingInfo": {"class_name": "Reference", "is_contained": False},
        "specimen": {"class_name": "Reference", "is_contained": False},
        "bodySite": {"class_name": "CodeableConcept", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "relevantHistory": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        instantiatesCanonical: list["str"] = None,
        instantiatesUri: list["str"] = None,
        basedOn: list["Reference"] = None,
        replaces: list["Reference"] = None,
        requisition: "Identifier" = None,
        status: "str" = None,
        intent: "str" = None,
        category: list["CodeableConcept"] = None,
        priority: "str" = None,
        doNotPerform: "bool" = None,
        code: "CodeableConcept" = None,
        orderDetail: list["CodeableConcept"] = None,
        quantityQuantity: "Quantity" = None,
        quantityRatio: "Ratio" = None,
        quantityRange: "Range" = None,
        subject: "Reference" = None,
        encounter: "Reference" = None,
        occurrenceDateTime: "str" = None,
        occurrencePeriod: "Period" = None,
        occurrenceTiming: "Timing" = None,
        asNeededBoolean: "bool" = None,
        asNeededCodeableConcept: "CodeableConcept" = None,
        authoredOn: "str" = None,
        requester: "Reference" = None,
        performerType: "CodeableConcept" = None,
        performer: list["Reference"] = None,
        locationCode: list["CodeableConcept"] = None,
        locationReference: list["Reference"] = None,
        reasonCode: list["CodeableConcept"] = None,
        reasonReference: list["Reference"] = None,
        insurance: list["Reference"] = None,
        supportingInfo: list["Reference"] = None,
        specimen: list["Reference"] = None,
        bodySite: list["CodeableConcept"] = None,
        note: list["Annotation"] = None,
        patientInstruction: "str" = None,
        relevantHistory: list["Reference"] = None,
    ):

        self.resourceType = "ServiceRequest"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.instantiatesCanonical = instantiatesCanonical or []
        self.instantiatesUri = instantiatesUri or []
        self.basedOn = basedOn or []
        self.replaces = replaces or []
        self.requisition = requisition
        self.status = status
        self.intent = intent
        self.category = category or []
        self.priority = priority
        self.doNotPerform = doNotPerform
        self.code = code
        self.orderDetail = orderDetail or []
        self.quantityQuantity = quantityQuantity
        self.quantityRatio = quantityRatio
        self.quantityRange = quantityRange
        self.subject = subject
        self.encounter = encounter
        self.occurrenceDateTime = occurrenceDateTime
        self.occurrencePeriod = occurrencePeriod
        self.occurrenceTiming = occurrenceTiming
        self.asNeededBoolean = asNeededBoolean
        self.asNeededCodeableConcept = asNeededCodeableConcept
        self.authoredOn = authoredOn
        self.requester = requester
        self.performerType = performerType
        self.performer = performer or []
        self.locationCode = locationCode or []
        self.locationReference = locationReference or []
        self.reasonCode = reasonCode or []
        self.reasonReference = reasonReference or []
        self.insurance = insurance or []
        self.supportingInfo = supportingInfo or []
        self.specimen = specimen or []
        self.bodySite = bodySite or []
        self.note = note or []
        self.patientInstruction = patientInstruction
        self.relevantHistory = relevantHistory or []

    @classmethod
    def from_dict(cls, data: dict) -> "ServiceRequest":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ServiceRequest":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for ClinicalUseDefinition. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Expression import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Range import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class OtherTherapy(FhirBaseModel):
    """Information about the use of the medicinal product in relation to other therapies described as part of the contraindication.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept relationshipType: The type of relationship between the product indication/contraindication and another therapy
    :param CodeableReference treatment: Reference to a specific medication, substance etc. as part of an indication or contraindication
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "relationshipType": {"class_name": "CodeableConcept", "is_contained": False},
        "treatment": {"class_name": "CodeableReference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        relationshipType: "CodeableConcept" = None,
        treatment: "CodeableReference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.relationshipType = relationshipType
        self.treatment = treatment

    @classmethod
    def from_dict(cls, data: dict) -> "ClinicalUseDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ClinicalUseDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Contraindication(FhirBaseModel):
    """Specifics for when this is a contraindication.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableReference diseaseSymptomProcedure: The situation that is being documented as contraindicating against this item
    :param CodeableReference diseaseStatus: The status of the disease or symptom for the contraindication
    :param CodeableReference comorbidity: A comorbidity (concurrent condition) or coinfection
    :param Reference indication: The indication which this is a contraidication for
    :param Expression applicability: An expression that returns true or false, indicating whether the indication is applicable or not, after having applied its other elements
    :param OtherTherapy otherTherapy: Information about use of the product in relation to other therapies described as part of the contraindication
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "diseaseSymptomProcedure": {
            "class_name": "CodeableReference",
            "is_contained": False,
        },
        "diseaseStatus": {"class_name": "CodeableReference", "is_contained": False},
        "comorbidity": {"class_name": "CodeableReference", "is_contained": False},
        "indication": {"class_name": "Reference", "is_contained": False},
        "applicability": {"class_name": "Expression", "is_contained": False},
        "otherTherapy": {"class_name": "OtherTherapy", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        diseaseSymptomProcedure: "CodeableReference" = None,
        diseaseStatus: "CodeableReference" = None,
        comorbidity: list["CodeableReference"] = None,
        indication: list["Reference"] = None,
        applicability: "Expression" = None,
        otherTherapy: list["OtherTherapy"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.diseaseSymptomProcedure = diseaseSymptomProcedure
        self.diseaseStatus = diseaseStatus
        self.comorbidity = comorbidity or []
        self.indication = indication or []
        self.applicability = applicability
        self.otherTherapy = otherTherapy or []

    @classmethod
    def from_dict(cls, data: dict) -> "ClinicalUseDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ClinicalUseDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Indication(FhirBaseModel):
    """Specifics for when this is an indication.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableReference diseaseSymptomProcedure: The situation that is being documented as an indicaton for this item
    :param CodeableReference diseaseStatus: The status of the disease or symptom for the indication
    :param CodeableReference comorbidity: A comorbidity or coinfection as part of the indication
    :param CodeableReference intendedEffect: The intended effect, aim or strategy to be achieved
    :param Range durationRange: Timing or duration information
    :param str durationString: Timing or duration information
    :param Reference undesirableEffect: An unwanted side effect or negative outcome of the subject of this resource when being used for this indication
    :param Expression applicability: An expression that returns true or false, indicating whether the indication is applicable or not, after having applied its other elements
    :param OtherTherapy otherTherapy: The use of the medicinal product in relation to other therapies described as part of the indication
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "diseaseSymptomProcedure": {
            "class_name": "CodeableReference",
            "is_contained": False,
        },
        "diseaseStatus": {"class_name": "CodeableReference", "is_contained": False},
        "comorbidity": {"class_name": "CodeableReference", "is_contained": False},
        "intendedEffect": {"class_name": "CodeableReference", "is_contained": False},
        "durationRange": {"class_name": "Range", "is_contained": False},
        "undesirableEffect": {"class_name": "Reference", "is_contained": False},
        "applicability": {"class_name": "Expression", "is_contained": False},
        "otherTherapy": {"class_name": "OtherTherapy", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        diseaseSymptomProcedure: "CodeableReference" = None,
        diseaseStatus: "CodeableReference" = None,
        comorbidity: list["CodeableReference"] = None,
        intendedEffect: "CodeableReference" = None,
        durationRange: "Range" = None,
        durationString: "str" = None,
        undesirableEffect: list["Reference"] = None,
        applicability: "Expression" = None,
        otherTherapy: list["OtherTherapy"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.diseaseSymptomProcedure = diseaseSymptomProcedure
        self.diseaseStatus = diseaseStatus
        self.comorbidity = comorbidity or []
        self.intendedEffect = intendedEffect
        self.durationRange = durationRange
        self.durationString = durationString
        self.undesirableEffect = undesirableEffect or []
        self.applicability = applicability
        self.otherTherapy = otherTherapy or []

    @classmethod
    def from_dict(cls, data: dict) -> "ClinicalUseDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ClinicalUseDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Interactant(FhirBaseModel):
    """The specific medication, product, food, substance etc. or laboratory test that interacts.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference itemReference: The specific medication, product, food etc. or laboratory test that interacts
    :param CodeableConcept itemCodeableConcept: The specific medication, product, food etc. or laboratory test that interacts
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "itemReference": {"class_name": "Reference", "is_contained": False},
        "itemCodeableConcept": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        itemReference: "Reference" = None,
        itemCodeableConcept: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.itemReference = itemReference
        self.itemCodeableConcept = itemCodeableConcept

    @classmethod
    def from_dict(cls, data: dict) -> "ClinicalUseDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ClinicalUseDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Interaction(FhirBaseModel):
    """Specifics for when this is an interaction.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Interactant interactant: The specific medication, product, food etc. or laboratory test that interacts
    :param CodeableConcept type: The type of the interaction e.g. drug-drug interaction, drug-lab test interaction
    :param CodeableReference effect: The effect of the interaction, for example "reduced gastric absorption of primary medication"
    :param CodeableConcept incidence: The incidence of the interaction, e.g. theoretical, observed
    :param CodeableConcept management: Actions for managing the interaction
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "interactant": {"class_name": "Interactant", "is_contained": True},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "effect": {"class_name": "CodeableReference", "is_contained": False},
        "incidence": {"class_name": "CodeableConcept", "is_contained": False},
        "management": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        interactant: list["Interactant"] = None,
        type: "CodeableConcept" = None,
        effect: "CodeableReference" = None,
        incidence: "CodeableConcept" = None,
        management: list["CodeableConcept"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.interactant = interactant or []
        self.type = type
        self.effect = effect
        self.incidence = incidence
        self.management = management or []

    @classmethod
    def from_dict(cls, data: dict) -> "ClinicalUseDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ClinicalUseDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class UndesirableEffect(FhirBaseModel):
    """Describe the possible undesirable effects (negative outcomes) from the use of the medicinal product as treatment.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableReference symptomConditionEffect: The situation in which the undesirable effect may manifest
    :param CodeableConcept classification: High level classification of the effect
    :param CodeableConcept frequencyOfOccurrence: How often the effect is seen
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "symptomConditionEffect": {
            "class_name": "CodeableReference",
            "is_contained": False,
        },
        "classification": {"class_name": "CodeableConcept", "is_contained": False},
        "frequencyOfOccurrence": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        symptomConditionEffect: "CodeableReference" = None,
        classification: "CodeableConcept" = None,
        frequencyOfOccurrence: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.symptomConditionEffect = symptomConditionEffect
        self.classification = classification
        self.frequencyOfOccurrence = frequencyOfOccurrence

    @classmethod
    def from_dict(cls, data: dict) -> "ClinicalUseDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ClinicalUseDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Warning(FhirBaseModel):
    """A critical piece of information about environmental, health or physical risks or hazards that serve as caution to the user. For example 'Do not operate heavy machinery', 'May cause drowsiness', or 'Get medical advice/attention if you feel unwell'.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str description: A textual definition of this warning, with formatting
    :param CodeableConcept code: A coded or unformatted textual definition of this warning
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        description: "str" = None,
        code: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.description = description
        self.code = code

    @classmethod
    def from_dict(cls, data: dict) -> "ClinicalUseDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ClinicalUseDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ClinicalUseDefinition(DomainResource):
    """A single issue - either an indication, contraindication, interaction or an undesirable effect for a medicinal product, medication, device or procedure.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Business identifier for this issue
    :param str type: indication | contraindication | interaction | undesirable-effect | warning
    :param CodeableConcept category: A categorisation of the issue, primarily for dividing warnings into subject heading areas such as "Pregnancy", "Overdose"
    :param Reference subject: The medication, product, substance, device, procedure etc. for which this is an indication
    :param CodeableConcept status: Whether this is a current issue or one that has been retired etc
    :param Contraindication contraindication: Specifics for when this is a contraindication
    :param Indication indication: Specifics for when this is an indication
    :param Interaction interaction: Specifics for when this is an interaction
    :param Reference population: The population group to which this applies
    :param str library: Logic used by the clinical use definition
    :param UndesirableEffect undesirableEffect: A possible negative outcome from the use of this treatment
    :param Warning warning: Critical environmental, health or physical risks or hazards. For example 'Do not operate heavy machinery', 'May cause drowsiness'
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "status": {"class_name": "CodeableConcept", "is_contained": False},
        "contraindication": {"class_name": "Contraindication", "is_contained": True},
        "indication": {"class_name": "Indication", "is_contained": True},
        "interaction": {"class_name": "Interaction", "is_contained": True},
        "population": {"class_name": "Reference", "is_contained": False},
        "undesirableEffect": {"class_name": "UndesirableEffect", "is_contained": True},
        "warning": {"class_name": "Warning", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        type: "str" = None,
        category: list["CodeableConcept"] = None,
        subject: list["Reference"] = None,
        status: "CodeableConcept" = None,
        contraindication: "Contraindication" = None,
        indication: "Indication" = None,
        interaction: "Interaction" = None,
        population: list["Reference"] = None,
        library: list["str"] = None,
        undesirableEffect: "UndesirableEffect" = None,
        warning: "Warning" = None,
    ):

        self.resourceType = "ClinicalUseDefinition"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.type = type
        self.category = category or []
        self.subject = subject or []
        self.status = status
        self.contraindication = contraindication
        self.indication = indication
        self.interaction = interaction
        self.population = population or []
        self.library = library or []
        self.undesirableEffect = undesirableEffect
        self.warning = warning

    @classmethod
    def from_dict(cls, data: dict) -> "ClinicalUseDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ClinicalUseDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for MedicinalProductIngredient. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.BackboneElement import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Identifier import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Ratio import *
from fhirmodels.R4.Reference import *
from fhirmodels.R4.Resource import *


class ReferenceStrength(FhirBaseModel):
    """Strength expressed in terms of a reference substance.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept substance: Relevant reference substance
    :param Ratio strength: Strength expressed in terms of a reference substance
    :param Ratio strengthLowLimit: Strength expressed in terms of a reference substance
    :param str measurementPoint: For when strength is measured at a particular point or distance
    :param CodeableConcept country: The country or countries for which the strength range applies
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "substance": {"class_name": "CodeableConcept", "is_contained": False},
        "strength": {"class_name": "Ratio", "is_contained": False},
        "strengthLowLimit": {"class_name": "Ratio", "is_contained": False},
        "country": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        substance: "CodeableConcept" = None,
        strength: "Ratio" = None,
        strengthLowLimit: "Ratio" = None,
        measurementPoint: "str" = None,
        country: list["CodeableConcept"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.substance = substance
        self.strength = strength
        self.strengthLowLimit = strengthLowLimit
        self.measurementPoint = measurementPoint
        self.country = country or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicinalProductIngredient":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicinalProductIngredient":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Strength(FhirBaseModel):
    """Quantity of the substance or specified substance present in the manufactured item or pharmaceutical product.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Ratio presentation: The quantity of substance in the unit of presentation, or in the volume (or mass) of the single pharmaceutical product or manufactured item
    :param Ratio presentationLowLimit: A lower limit for the quantity of substance in the unit of presentation. For use when there is a range of strengths, this is the lower limit, with the presentation attribute becoming the upper limit
    :param Ratio concentration: The strength per unitary volume (or mass)
    :param Ratio concentrationLowLimit: A lower limit for the strength per unitary volume (or mass), for when there is a range. The concentration attribute then becomes the upper limit
    :param str measurementPoint: For when strength is measured at a particular point or distance
    :param CodeableConcept country: The country or countries for which the strength range applies
    :param ReferenceStrength referenceStrength: Strength expressed in terms of a reference substance
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "presentation": {"class_name": "Ratio", "is_contained": False},
        "presentationLowLimit": {"class_name": "Ratio", "is_contained": False},
        "concentration": {"class_name": "Ratio", "is_contained": False},
        "concentrationLowLimit": {"class_name": "Ratio", "is_contained": False},
        "country": {"class_name": "CodeableConcept", "is_contained": False},
        "referenceStrength": {"class_name": "ReferenceStrength", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        presentation: "Ratio" = None,
        presentationLowLimit: "Ratio" = None,
        concentration: "Ratio" = None,
        concentrationLowLimit: "Ratio" = None,
        measurementPoint: "str" = None,
        country: list["CodeableConcept"] = None,
        referenceStrength: list["ReferenceStrength"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.presentation = presentation
        self.presentationLowLimit = presentationLowLimit
        self.concentration = concentration
        self.concentrationLowLimit = concentrationLowLimit
        self.measurementPoint = measurementPoint
        self.country = country or []
        self.referenceStrength = referenceStrength or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicinalProductIngredient":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicinalProductIngredient":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class SpecifiedSubstance(FhirBaseModel):
    """A specified substance that comprises this ingredient.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept code: The specified substance
    :param CodeableConcept group: The group of specified substance, e.g. group 1 to 4
    :param CodeableConcept confidentiality: Confidentiality level of the specified substance as the ingredient
    :param Strength strength: Quantity of the substance or specified substance present in the manufactured item or pharmaceutical product
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "group": {"class_name": "CodeableConcept", "is_contained": False},
        "confidentiality": {"class_name": "CodeableConcept", "is_contained": False},
        "strength": {"class_name": "Strength", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "CodeableConcept" = None,
        group: "CodeableConcept" = None,
        confidentiality: "CodeableConcept" = None,
        strength: list["Strength"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.group = group
        self.confidentiality = confidentiality
        self.strength = strength or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicinalProductIngredient":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicinalProductIngredient":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Substance(FhirBaseModel):
    """The ingredient substance.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept code: The ingredient substance
    :param Strength strength: Quantity of the substance or specified substance present in the manufactured item or pharmaceutical product
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "strength": {"class_name": "Strength", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "CodeableConcept" = None,
        strength: list["Strength"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.strength = strength or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicinalProductIngredient":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicinalProductIngredient":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class MedicinalProductIngredient(DomainResource):
    """An ingredient of a manufactured item or pharmaceutical product.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Identifier for the ingredient
    :param CodeableConcept role: Ingredient role e.g. Active ingredient, excipient
    :param bool allergenicIndicator: If the ingredient is a known or suspected allergen
    :param Reference manufacturer: Manufacturer of this Ingredient
    :param SpecifiedSubstance specifiedSubstance: A specified substance that comprises this ingredient
    :param Substance substance: The ingredient substance
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "role": {"class_name": "CodeableConcept", "is_contained": False},
        "manufacturer": {"class_name": "Reference", "is_contained": False},
        "specifiedSubstance": {
            "class_name": "SpecifiedSubstance",
            "is_contained": True,
        },
        "substance": {"class_name": "Substance", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: "Identifier" = None,
        role: "CodeableConcept" = None,
        allergenicIndicator: "bool" = None,
        manufacturer: list["Reference"] = None,
        specifiedSubstance: list["SpecifiedSubstance"] = None,
        substance: "Substance" = None,
    ):

        self.resourceType = "MedicinalProductIngredient"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier
        self.role = role
        self.allergenicIndicator = allergenicIndicator
        self.manufacturer = manufacturer or []
        self.specifiedSubstance = specifiedSubstance or []
        self.substance = substance

    @classmethod
    def from_dict(cls, data: dict) -> "MedicinalProductIngredient":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicinalProductIngredient":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Bundle. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.BackboneElement import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Identifier import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Resource import *
from fhirmodels.R4.Signature import *


class Link(FhirBaseModel):
    """A series of links that provide context to this bundle.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str relation: See http://www.iana.org/assignments/link-relations/link-relations.xhtml#link-relations-1
    :param str url: Reference details for the link
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        relation: "str" = None,
        url: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.relation = relation
        self.url = url

    @classmethod
    def from_dict(cls, data: dict) -> "Bundle":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Bundle":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Search(FhirBaseModel):
    """Information about the search process that lead to the creation of this entry.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str mode: match | include | outcome - why this is in the result set
    :param float score: Search ranking (between 0 and 1)
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        mode: "str" = None,
        score: "float" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.mode = mode
        self.score = score

    @classmethod
    def from_dict(cls, data: dict) -> "Bundle":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Bundle":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Request(FhirBaseModel):
    """Additional information about how this entry should be processed as part of a transaction or batch.  For history, it shows how the entry was processed to create the version contained in the entry.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str method: GET | HEAD | POST | PUT | DELETE | PATCH
    :param str url: URL for HTTP equivalent of this entry
    :param str ifNoneMatch: For managing cache currency
    :param str ifModifiedSince: For managing cache currency
    :param str ifMatch: For managing update contention
    :param str ifNoneExist: For conditional creates
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        method: "str" = None,
        url: "str" = None,
        ifNoneMatch: "str" = None,
        ifModifiedSince: "str" = None,
        ifMatch: "str" = None,
        ifNoneExist: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.method = method
        self.url = url
        self.ifNoneMatch = ifNoneMatch
        self.ifModifiedSince = ifModifiedSince
        self.ifMatch = ifMatch
        self.ifNoneExist = ifNoneExist

    @classmethod
    def from_dict(cls, data: dict) -> "Bundle":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Bundle":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Response(FhirBaseModel):
    """Indicates the results of processing the corresponding 'request' entry in the batch or transaction being responded to or what the results of an operation where when returning history.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str status: Status response code (text optional)
    :param str location: The location (if the operation returns a location)
    :param str etag: The Etag for the resource (if relevant)
    :param str lastModified: Server's date time modified
    :param Resource outcome: OperationOutcome with hints and warnings (for batch/transaction)
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "outcome": {"class_name": "Resource", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        status: "str" = None,
        location: "str" = None,
        etag: "str" = None,
        lastModified: "str" = None,
        outcome: "Resource" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.status = status
        self.location = location
        self.etag = etag
        self.lastModified = lastModified
        self.outcome = outcome

    @classmethod
    def from_dict(cls, data: dict) -> "Bundle":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Bundle":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Entry(FhirBaseModel):
    """An entry in a bundle resource - will either contain a resource or information about a resource (transactions and history only).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Link link: Links related to this entry
    :param str fullUrl: URI for resource (Absolute URL server address or URI for UUID/OID)
    :param Resource resource: A resource in the bundle
    :param Search search: Search related information
    :param Request request: Additional execution information (transaction/batch/history)
    :param Response response: Results of execution (transaction/batch/history)
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "link": {"class_name": "Link", "is_contained": True},
        "resource": {"class_name": "Resource", "is_contained": False},
        "search": {"class_name": "Search", "is_contained": True},
        "request": {"class_name": "Request", "is_contained": True},
        "response": {"class_name": "Response", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        link: list["Link"] = None,
        fullUrl: "str" = None,
        resource: "Resource" = None,
        search: "Search" = None,
        request: "Request" = None,
        response: "Response" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.link = link or []
        self.fullUrl = fullUrl
        self.resource = resource
        self.search = search
        self.request = request
        self.response = response

    @classmethod
    def from_dict(cls, data: dict) -> "Bundle":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Bundle":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Bundle(DomainResource):
    """A container for a collection of resources.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Identifier identifier: Persistent identifier for the bundle
    :param str type: document | message | transaction | transaction-response | batch | batch-response | history | searchset | collection
    :param str timestamp: When the bundle was assembled
    :param int total: If search, the total number of matches
    :param Link link: Links related to this Bundle
    :param Entry entry: Entry in the bundle - will have a resource or information
    :param Signature signature: Digital Signature
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "link": {"class_name": "Link", "is_contained": True},
        "entry": {"class_name": "Entry", "is_contained": True},
        "signature": {"class_name": "Signature", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        identifier: "Identifier" = None,
        type: "str" = None,
        timestamp: "str" = None,
        total: "int" = None,
        link: list["Link"] = None,
        entry: list["Entry"] = None,
        signature: "Signature" = None,
    ):

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.identifier = identifier
        self.type = type
        self.timestamp = timestamp
        self.total = total
        self.link = link or []
        self.entry = entry or []
        self.signature = signature

    @classmethod
    def from_dict(cls, data: dict) -> "Bundle":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Bundle":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Period. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R4.Extension import *


class Period(FhirBaseModel):
    """Base StructureDefinition for Period Type: A time period defined by a start and end date and optionally time.
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param str start: Starting time with inclusive boundary
    :param str end: End time with inclusive boundary, if not ongoing
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        start: "str" = None,
        end: "str" = None,
    ):

        self.id = id
        self.extension = extension or []
        self.start = start
        self.end = end

    @classmethod
    def from_dict(cls, data: dict) -> "Period":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Period":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()
